package com.aucma.report.service;

import java.util.List;
import com.aucma.report.domain.ReportRepairMeasures;

/**
 * 返修措施维护Service接口
 * 
 * @author Yinq
 * @date 2023-11-21
 */
public interface IReportRepairMeasuresService 
{
    /**
     * 查询返修措施维护
     * 
     * @param objId 返修措施维护主键
     * @return 返修措施维护
     */
    public ReportRepairMeasures selectReportRepairMeasuresByObjId(Long objId);

    /**
     * 查询返修措施维护列表
     * 
     * @param reportRepairMeasures 返修措施维护
     * @return 返修措施维护集合
     */
    public List<ReportRepairMeasures> selectReportRepairMeasuresList(ReportRepairMeasures reportRepairMeasures);

    /**
     * 新增返修措施维护
     * 
     * @param reportRepairMeasures 返修措施维护
     * @return 结果
     */
    public int insertReportRepairMeasures(ReportRepairMeasures reportRepairMeasures);

    /**
     * 修改返修措施维护
     * 
     * @param reportRepairMeasures 返修措施维护
     * @return 结果
     */
    public int updateReportRepairMeasures(ReportRepairMeasures reportRepairMeasures);

    /**
     * 批量删除返修措施维护
     * 
     * @param objIds 需要删除的返修措施维护主键集合
     * @return 结果
     */
    public int deleteReportRepairMeasuresByObjIds(Long[] objIds);

    /**
     * 删除返修措施维护信息
     * 
     * @param objId 返修措施维护主键
     * @return 结果
     */
    public int deleteReportRepairMeasuresByObjId(Long objId);
}
